# luketils

TODO add badges from PyPi and all the fun stuff

`luketils` is a Python utility package aimed at machine learning practitioners.
The goal of the package is to provide useful utilities in a coherently designed and
powerful API.

_Call for Contributions:_ *luketils is actively seeking contributions!  Please see the [Call for Contributions](#call_for_contributions) section below!*

## Quick Links

- [API Docs] (coming soon)!
- Examples
- Contributing

## Call for Contributions

I'm hoping to crowdsource `luketils` and gather as many
useful machine learning oriented Python utilities as possible.  Have something useful?
Open a PR!  I'll give it a review!  

Don't have an idea?  Check out the [Contributions Welcome] hotlist!

## Thanks

Thank you to all of our wonderful contributors!
